#
# spec file for package guake
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Need to re-define pythons to get pyproject_* macros working
%define pythons python3
Name:           guake
Version:        3.10
Release:        6.1
Summary:        Drop-down terminal for GNOME
License:        GPL-2.0-or-later
URL:            https://guake.github.io/
Source0:        https://files.pythonhosted.org/packages/source/g/guake/guake-%{version}.tar.gz
# Needed to install desktop app supporting files to FHS location; the PyPI
# source misses this, being geared towards installing everything to python module dir
Source1:        https://raw.githubusercontent.com/Guake/guake/%{version}/guake/paths.py.in
Source2:        %{name}.rpmlintrc
# PATCH-FEATURE-OPENSUSE guake-Makefile-generate-install-paths.patch badshah400@gmail.com -- Ensure data paths in python script point to the correct system installed paths
Patch0:         guake-Makefile-generate-install-paths.patch
BuildRequires:  fdupes
BuildRequires:  glib2-tools
BuildRequires:  gobject-introspection
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools >= 57.5.0
BuildRequires:  python3-setuptools_scm
BuildRequires:  python3-wheel
BuildRequires:  update-desktop-files
%if 0%{?suse_version} < 1600
Requires:       libutempter0
%endif
Requires:       python3-cairo
Requires:       python3-dbus-python
Requires:       python3-gobject-Gdk
Requires:       python3-pyaml
Requires:       python3-typing
Recommends:     %{name}-doc
BuildArch:      noarch
# SECTION BuildRequires for documentation
BuildRequires:  python3-Sphinx
BuildRequires:  python3-reno
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:  python3-sphinxcontrib-programoutput
# /SECTION

%lang_package

%description
Guake is a dropdown terminal made for the GNOME desktop environment.

%package doc
Summary:        Documentation for Guake
Requires:       %{name}

%description doc
Guake is a dropdown terminal made for the GNOME desktop environment.

This package provides the HTML documentation for Guake.

%prep
%autosetup -p1 -n guake-%{version}
cp %{SOURCE1} guake/

%build
# Note: At least `make generate-paths` needs to run before pyproject_wheel to set up the correct paths in guake/paths.py
%make_build PREFIX=%{_prefix} generate-desktop generate-mo generate-paths
%pyproject_wheel

# Build documentation
# non-parallel to avoid non-determinism in man/guake.1 from https://github.com/sphinx-doc/sphinx/issues/6714
make -C docs man html
rm docs/_build/html/.buildinfo

%install
%pyproject_install
%make_build DESTDIR=%{buildroot} PREFIX=%{_prefix} install-locale install-schemas

# Install documentation
mkdir -p %{buildroot}%{_docdir}/guake
cp -r docs/_build/html %{buildroot}%{_docdir}/guake/
mkdir -p %{buildroot}%{_mandir}/man1
install -m0644 docs/_build/man/*.1 %{buildroot}%{_mandir}/man1/guake.1

%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{python3_sitelib}/guake/

%files
%doc README.rst
%license COPYING
%{_bindir}/guake
%{_bindir}/guake-toggle
%{_mandir}/man1/guake.1%{?ext_man}
%{_datadir}/applications/*.desktop
%{_datadir}/glib-2.0/schemas/*
%{_datadir}/guake/
%{_datadir}/metainfo/*.metainfo.xml
%{_datadir}/pixmaps/*.png
%{python3_sitelib}/guake/
%{python3_sitelib}/guake-%{version}.dist-info

%files doc
%license COPYING
%doc %{_docdir}/guake/html

%files lang -f %{name}.lang
%license COPYING

%changelog
* Mon Mar 10 2025 Marius Grossu <marius.grossu@suse.com>
- change the docs dependencies to python3-sphinx_rtd_theme and
  python3-sphinxcontrib-programoutput
* Thu Jan 23 2025 Sebastian Wagner <sebix@sebix.at>
- add python311-sphinx_rtd_theme as build dep to fix doc build on ARM
* Fri Jan 17 2025 Thorsten Kukuk <kukuk@suse.com>
- Disable libutempter, it doesn't work anymore with the switch
  from utmp to systemd-logind
* Tue Apr  2 2024 John Vandenberg <jayvdb@gmail.com>
- Update URL to https://guake.github.io/
* Sun Nov 19 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Workaround Sphinx issue to generate reproducible docs (boo#1102408)
* Tue Jun 27 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.10:
  * Fix 0 timestamp #1857 #1950 [gh#Guake/guake#2102].
  * search engine can be set to preference [gh#Guake/guake#2125].
  * Added custom search engine input #2088 [gh#Guake/guake#2134].
  * Include names of processes in PromptQuitDialog
    [gh#Guake/guake#2135].
  * Add new hotkey to open new tab in same directory
    [gh#Guake/guake#2136].
  * Add pin button to temporarily prevent hiding when losing focus
    [gh#Guake/guake#2138].
  * Add pre-commit config and apply all fixes
    [gh#Guake/guake#2139].
  * Add a new hotkey to select all text in the current terminal
    [gh#Guake/guake#2145].
  * Run -e in new tabs generated by split vertical/horizontal
    [gh#Guake/guake#2172].
  * Add global hotkey instructions to docs [gh#Guake/guake#2173].
  * Open a new guake tab if guake is called with guake [PATH] and
    no other flags. [gh#Guake/guake#2174].
  * Save font size when changing zoom level with keyboard
    shortcuts [gh#Guake/guake#2175].
- Add guake-Makefile-generate-install-paths.patch: Modify paths in
  the Makefile to reflect actual paths installed to by rpm
  package.
- Build and install workflow overhaul based on upstream Makefile:
  * Run make targets to generate desktop, locale files, and set-up
    the correct system paths in paths.py (generate-paths)
  * Use pyproject_wheel and pyproject_install to build guake
    python modules.
  * Run make install-schemas to install desktop app data.
  * Build and install documentation in the form of HTML (split out
    separate doc package) and man.
- Drop outdated NEWS.rst package from installed files.
- Add guake.rpmlintrc file to suppress false positive
  warnings and errors.
* Sun May 21 2023 Andreas Stieger <andreas.stieger@gmx.de>
- fix missing dependency on PyYAML (boo#1211574)
* Tue Nov 29 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 3.9.0:
  * return of the --execute-command flag with slightly adjusted semantics,
  * a new system for setting terminal parameters with yaml files and various fixes
  * Fix custom label not working
  * fix fullscreen using pointer on several monitors
  * Add TERM_PROGRAM environment variable like other well-known terminals
  * Add open link under terminal cursor
  * Fix split terminal did not preverse font scale
  * Save layout when splitting/closing split panes
  * Add command line flag to get tab number/position from UUID
  * Reintroduce execute_command dbus hook
* Mon Feb 14 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.8.5:
  * Fixed readthedoc system.
  * Fix system font only being applied to last tab
    [gh#Guake/guake#1954].
  * Use keycode for keybindings [gh#Guake/guake#1953].
  * Replace ｜ with non unicode dependent | [gh#Guake/guake#1966].
  * Add pbr fallback [gh#Guake/guake#1964].
  * Fix vte spawn_sync runtime check failed [gh#Guake/guake#1974].
  * Add GUAKE_ENABLE_WAYLAND environment variable
    [gh#Guake/guake#1975].
  * Switch default for hide tab bar if only one tab to disabled
    [gh#Guake/guake#1983].
  * Changed default keybindig to toggle hide on lose focus. Fix
    gh#Guake/guake#1719 [gh#Guake/guake#1988].
  * Drop pbr [gh#Guake/guake#1991].
  * Fix translation file inclusion [gh#Guake/guake#2004].
  * feature: --is-visible option [gh#Guake/guake#2008].
  * Reinstate double click to open tabs [gh#Guake/guake#2010].
  * Fix deepsource complaints [gh#Guake/guake#2009].
  * Fix arbitrary execution via dbus security flaw
    [gh#Guake/guake#2017].
  * Eliminate redundant terminal spawning [gh#Guake/guake#2020].
  * Translation and documentation updates.
- Use PyPI source tarball instead of GitHub tag-ref'ed ones to
  avoid incorrect reading of the version by build scripts; see
  <https://guake.readthedocs.io/en/latest/user/installing.html#install-from-source>
- Add 'paths.py.in' as additional source; missed by PyPI tarball.
- Drop remove_setuptools_scm.patch: No longer needed in light of
  above; also drop associated workaround in %%setup.
- New BuildRequires: python3-setuptools_scm needed for proper
  version determination.
- Explicitly list egg-info dir in file-list to ensure proper
  versioning has been applied during build.
- Enforce python3-setuptools >= 57.5 for BuildRequires as required
  by upstream.
- Drop PBR_VERSION workaround from make install: No longer needed.
- Fix an EOL encoding.
- Drop a useless placeholder dir from docs.
* Fri Feb  4 2022 Sebastian Wagner <sebix@sebix.at>
- add new patch remove_setuptools_scm.patch to remove the dependency on setuptools_scm
- write the version guake/_version.py in prep step.
- Update to version 3.8.2:
  - Fix system font only being applied to last tab by @Davidy22 in #1954
  - Use keycode for keybindings by @vantu5z in #1953
  - Replace ｜ with non unicode dependent | by @Davidy22 in #1966
  - Update news file by @Davidy22 in #1951
  - Add pbr fallback by @Davidy22 in #1964
  - Fix vte spawn_sync runtime check failed by @mlouielu in #1974
  - Add GUAKE_ENABLE_WAYLAND environment variable by @VitalyAnkh in #1975
  - Add instructions for PPA install by @Davidy22 in #1961
  - Switch default for hide tab bar if only one tab to disabled by @Davidy22 in #1983
  - Changed default keybindig to toggle hide on lose focus. Fix #1719 by @jcfstabile in #1988
  - Fix module gi not found when make run by @jcfstabile in #1989
  - Revert "Fix module gi not found when make run " by @mlouielu in #1992
  - Drop pbr by @eli-schwartz in #1991
  - Bump pipenv from 2021.5.29 to 2022.1.8 by @dependabot in #2005
  - Fix upload to pypi test by @Davidy22 in #2002
  - Fix translation file inclusion by @Davidy22 in #2004
  - feature: --is-visible option #1926 by @rjeb in #2008
  - Reinstate double click to open tabs by @Davidy22 in #2010
  - Fix deepsource complaints by @Davidy22 in #2009
  - ci: enable upload to pypi by @Davidy22 in #2007
  - Generate release notes for 3.8.2 by @Davidy22 in #2012
  - Update translation from Weblate by @gsemet in #2013
  - Revert "doc: update NEWS.rst" by @Davidy22 in #2014
  - ci: no pipeline on pull_request by @gsemet in #2016
  - Revert "ci: no pipeline on pull_request" by @Davidy22 in #2018
  - Fix arbitrary execution via dbus security flaw by @Davidy22 in #2017
  - Eliminate redundant terminal spawning by @Davidy22 in #2020
  - Generate release notes for 3.8.2 by @Davidy22 in #2024
* Wed Nov 10 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.8.1:
  * Feature request: Setting line-spacing / line-height
    (gh#Guake/guake#849).
  * Support of short term focus loss and avoid folding
  * (gh#Guake/guake#1643).
  * Some shortcut keys are abnormal (gh#Guake/guake#1939).
  * Moved guake.desktop.metainfo.xml to $datadir.
- Drop guake-follow-focus-with-dual-monitors.patch: Incorporated
  upstream.
  /nov-------------------------------------------------------------------
* Wed Nov 10 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add guake-follow-focus-with-dual-monitors.patch: Fix issue where
  guake follows mouse focus when have 2 monitors
  [gh#Guake/guake#1775, gh#Guake/guake#1761, boo#1187177].
* Tue Jun  8 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not own /usr/share/pixmaps, and /usr/share/metainfo,  but only
  content thereof.
* Mon Jun  7 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Drop pandoc BuildRequires: not required.
* Tue Feb 18 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.7.0:
  * Fixes the bug when "New Tab" or "Split Terminal" resets colors
    set by "--bgcolor" command.
  * Custom colors for every terminal added. Colors are saved
    alongside with another tab info. "Reset custom colors" menu
    item added to hte tab context menu.
  * Resetting colors of the current page. Managing background and
    foreground colors of the current terminal.
  * Adds an option to display only the last directory on the
    current path as the tab name.
  * New Features:
  - Add tab selection popover in each notebook
  - Add fullscreen hide tabbar option
  - List new features here followed by the ticket number, for
    example:
  * Resetting colors of the current page.
  * Setting of background and foreground colors and resetting
    colors of the focused terminal.
  - Setting of background and foreground colors and resetting
    colors of the current terminal (not the focused one).
  - Add --select-terminal and --selected-terminal options to
    Guake CLI
  - Adds an option to display only the last directory on the
    current path as the tab name.
  - Reworked the tab name selection to use a drop-down menu.
  - Unfullscreen through D-Bus interface, as well as through
    CLI.
  * Bug Fixes
  - Fix Crash (TypeError) when common keys are found in config
    [#1713]
  - Fixes the bug when "New Tab" or "Split Terminal" resets
    colors set by "--bgcolor" command.
  - Add pew package to Pipfile
  - When composited changed, it will update Guake window visual
    to make it transparent
  - Fix fullscreen/unfullscreen not handle correctly when
    trigger by wm
  - Fix search revealer causing terminal unclickable at bottom
    right
  - adding a new tab no longer shows the hidden scrollbars on
    other tabs
  - Remove no need window draw callback
  - Fix make uninstall not cleaning up properly
  - Update some dependencies for build environment
  - Update the error message on missing dependencies (ex: when
    use 'pip install' guake)
  * Translation updates.
- Use %%{name}-%%{version} name for source tarball.
- Split out separate -lang package.
- Remove spurious translation files not installed in localedir.
- Run make with multiple parallel threads.
* Thu May 16 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.6.3:
  * Add drag-n-drop to terminal (text & uris)
  * When scrolling with "shift" (1 page) or "shift + ctrl" (4
    pages) it will be faster (gh#Guake/guake#271)
  * Add schema_version check for tabs session restore
  * Add save/restore terminal split for tabs session -
    Save/Restore terminal split by pre-order traversal full binary
    tree in list
  * Bump tabs session schema_version to 2 (to support terminal
    split)
  * Lazy restore terminal split until Guake is visible
  * Manage terminal signal handler by handler_ids
  * Avoid spurious resize event when showing fullscreened window
  * Make sure workspace-specific-tab-sets only enable on X11
    backend (due to wnck)
  * Add install/uninstall-dev-locale to support dev locale
  * Fix DualTerminalBox grab focus when remove dead child
  * Support customize prefix for make
  * Fix re-focus on terminal after rename dialog destroy
  * Fix split terminal by menu will not follow last terminal cwd
    (if option set)
  * Fix delete_shell using os.waitpid (should not use it)
* Mon Apr 29 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.6.1:
  * new feature: search in current terminal
  * new feature: session saving
  * new feature: settings export and import
  * various fixes to the core
  * minor build system fixes
  * translation updates
* Tue Apr 23 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.5.0:
  * new hotkey (CTRL+SHIFT+H) to open new tab in home directory
  * "New tab" button (gh#Guake/guake#1471)
  * Open new tab by double-clicking on the tab bar
  * Add new context menu on the notebook
  * Add a CLI option to change palette scheme
    (gh#Guake/guake#1345)
  * Bold text is also bright (>= VTE 0.52 only)
  * guake --split-vertical and --split-horizontal split the
    current
  * tab just like the context menu does
  * Optional close buttons for tabs (disabled by default)
  * Guake can now provide a set of tabs per workspace
  * Reverse transparency slider to be more meaningful
    (gh#Guake/guake#1501)
  * Fix command-line select tab behavior (gh#Guake/guake#1492)
  * removed duplicate event bind? previously I had issue where
    quick-open event would be fired twice because of this.
  * fix settings only applied to the active workspace if more the
    1 is used
  * fix prompt quit dialog numbers when more then 1 workspace is
    used
  * Updated translations.
* Thu Oct  4 2018 badshah400@gmail.com
- Update to version 3.4.0:
  * Split and resize terminals via mouse or keyboard shortcuts.
  * "New terminal" / "Rename terminal" / "Close terminal" items
    has been removed from the terminal context menu. They are
    still available on the tab context menu.
  * Fix multiline selection right click (gh#Guake/guake#1413).
  * Fix tab name (gh#Guake/guake#1017).
  * fixes jumping preference window (gh#Guake/guake#1149).
  * fix no focus after closing a split terminal
    (gh#Guake/guake#1421).
  * Add note about shell that does not support --login parameter
    (gh#Guake/guake#469).
  * Updated translations.
* Thu Aug 23 2018 badshah400@gmail.com
- Add python3-gobject-Gdk to Requires; fixes boo#1102963.
* Mon Jul 23 2018 badshah400@gmail.com
- Update to version 3.3.2:
  * Travis build cleaned build artifacts before deployment,
    leading to missing files when built in the CI.
- Changesn from version 3.3.1:
  * Don't translate application icon (this finally fixes Guake
    application icon not being displayed with German locale, which
    was only partially resolved with gh#Guake/guake#1320)
  * Install of Guake through pip install was broken; fixed.
* Sat Jul 14 2018 badshah400@gmail.com
- Update to version 3.3.0:
  * Wayland is a bit more well supported. The X11 backend is now
    used by default for GDK and it seems to make the shortcut
    works under most situation.
  * A new command has been added: guake-toggle, should be faster
    than guake -t. You can use it when you register the global
    shortcut manually (X11 or Wayland).
* Sun Jun  3 2018 badshah400@gmail.com
- Update to version 3.2.2:
  * Fix transparency regression on ubuntu composite
    (gh#Guake/guake#1333).
  * Fix transparency issue.
  * Fix right-click on link.
  * Fix bad css override on check tab background
    (gh#Guake/guake#1326).
  * Fix Guake application icon not displayed with German locale.
  * Fix ctrl+click on hyperlinks on VTE 0.50
    (gh#Guake/guake#1295).
  * Fixed "Gruvbox Dark" color palette (swapped foreground and
    background).
  * Swapped foreground and background colors for palettes added in
    commit #58842e9.
  * Add option groupes to the bootstrap scripts.
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 3.2.1:
  * Introduce Nord: a new nice, clean new palette theme is
    available for Guake users (gh#Guake/guake#1275)
  * Fix duplication in theme list (gh#Guake/guake#1304)
  * Fix right click selection in Midnight Commander
  * Corrected usage of Vte.Regex.new_for_match to fix regular
    expression matching (hyperlinks, quick open) on VTE >0.50
    (gh#Guake/guake#1295). URL with ' (simple quote) and ()
    (parenthesis) are now captured by hyperlink matcher. User can
    still select the URL in the terminal if he wishes to capture
    the exact url, before doing a Ctrl+click or a right click.
  * Fix "Grubbox Dark" theme
  * Updated translations.
- Changes from version 3.2.0:
  * Allow user to select the theme within the preference UI
  * Selected tab use "selected highlight" color from theme
    (gh#Guake/guake##1036)
  * Updated translations.
* Mon Apr 16 2018 sebix@sebix.at
- Use gobject-introspection for typelib library detection.
* Sat Apr 14 2018 sebix@sebix.at
- update to version 3.1.1:
  * New Features
  * Quick open displays a combobox with predefined settings for Visual Studio Code, Atom and Sublime Text.
  * Bug Fixes
  * Fix hyperlink VTE
- update to version 3.1.0:
  * Release Summary
  * This version of Guake brings mostly bug fixes, and some new features like "Quick Open on selection".
    I have also reworked internally the Quick Open so that it can automatically open files from logs
    from pytest and other python development tools output. However, there might still some false
    positive on the hovering of the mouse in the terminal, the most famous being the output of ``ls -l``
    which may have the mouse looks like it sees hyperlinks on the terminal everywhere. Click does
    nothing but its an annoying limitation.
  * New Features:
  - New "start at login" option in the settings (only for GNOME) #251
  - Add ``--verbose``/``-v`` parameter to enable debug logging. Please note the existing ``-v`` (for
    version number) has been renamed ``-V``.
  - Support for hyperlink VTE extension (`described
    here <https://gist.github.com/egmontkob/eb114294efbcd5adb1944c9f3cb5feda>`__ ) #945 (Untested, as
    it requires VTE 0.50)
  - Add great color palettes from `Guake Color
    Scheme <https://github.com/ziyenano/Guake-Color-Schemes>
  - Allow application to capture right click (ex: Midnight commander). #1096. It is still possible to
    show the contextual menu with Shift+right click.
  * Bug Fixes:
  - delete tab even without libutempter (#1198)
  - Fix crash when changing command file #1229
  - fix ``import sys`` in ``simplegladeapp.py``
  - change scope of ``which_align`` variable in ``pref.py`` (#1225)
  - Fix user interface translations #1228
  - Fix several issues on Quick Edit:
  - There might be broken translations, or not up-to-date language support by Guake. A global refresh
    of all existing translations would be welcomed. Most has not been updated since the transition to
    Guake 3, so these languages support might probably be unfunctional or at least partialy
    localized.
- remove fix-simplegladeapp.patch, merged upstream
* Fri Mar 30 2018 sebix@sebix.at
- initial package for version 3.0.5
- add fix-simplegladeapp.patch to fix runtime bug
